@@ -107,8 +107,8 @@ var NAVTREEINDEX =
 "keys_8h.html#aff405f056c4afbeb87df6f663178b993",
 "page_streams.html#ssec_produce",
 "stream_8c.html#ac1d281db6111363227781192d2eb56c7",
-"structpw__core__methods.html#a96ae294d1a899b90a6a8d3458a300fe2",
-"structpw__properties.html#a0a8ffc1e4b80fb04baa20a1422f349de"
+"structpw__core__methods.html#a7e77a9289cd4ba827a7082109d207459",
+"structpw__properties.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
